@@ -5,9 +5,10 @@
 #' @keywords misc utilities
 #' @concept physiology
 #' @concept medicine
+#' @concept renal
 #' @concept blood
 #' @concept ideal weight
 #' @docType package
 #' @useDynLib physiology, .registration = TRUE
 #' @importFrom Rcpp sourceCpp
-NULL
+"_PACKAGE"
