@@ -1,20 +1,20 @@
 ## ---- echo=FALSE, fig.width=7, fig.height=7------------------------------
 library(physiology)
 library(ggplot2)
-library(reshape2)
 hts <- seq(from = 1.5, to = 2.0, by = 0.01)
+male <- rep(T, times = length(hts))
 suppressWarnings({
   ideal_weights <- data.frame(
     "Height" = hts,
-    Devine = ideal_weight_Devine(height_m = hts, male = rep(T, times=length(hts))),
-    Broca = ideal_weight_Broca(height_m = hts, male = rep(T, times=length(hts))),
-    Robinson = ideal_weight_Robinson(height_m = hts, male = rep(T, times=length(hts))),
-    Miller = ideal_weight_Miller(height_m = hts, male = rep(T, times=length(hts))),
+    Devine = ideal_weight_Devine(height_m = hts, male = male),
+    Broca = ideal_weight_Broca(height_m = hts, male = male),
+    Robinson = ideal_weight_Robinson(height_m = hts, male = male),
+    Miller = ideal_weight_Miller(height_m = hts, male = male),
     Lemmens = ideal_weight_Lemmens(height_m = hts)
-    )
-  })
-p <- ggplot(melt(ideal_weights, id.vars = "Height"),
-            aes(x = Height, y = value, group = variable)) +
+  )
+})
+melt <- tidyr::gather(ideal_weights, key = "variable", value = "value", -Height)
+p <- ggplot(melt, aes(x = Height, y = value, group = variable)) +
   geom_line(aes(colour = variable)) +
   #  scale_x_continuous(breaks = seq(0.5, 3, 0.5), limits = c(0.5, 3)) +
   #scale_y_continuous(breaks = seq(0, 5, 1), limits = c(0, 5)) +
