@@ -2,14 +2,15 @@ context("ventilation")
 
 test_that("anatomic deadspace for a child", {
   expect_equal(
-    deadspace_anatomic_child(ideal_weight_kg = 10),
+    expect_warning(deadspace_anatomic_child(ideal_weight_kg = 10)),
     deadspace_anatomic_child(ideal_weight_kg = 10, age_y = 6)
   )
   expect_equal(
     deadspace_anatomic_child(ideal_weight_kg = 10, age_y = 6),
     deadspace_anatomic_child(ideal_weight_kg = 10, age_y = 7)
   )
-  expect_equal(deadspace_anatomic_child(ideal_weight_kg = 10), 22)
+  expect_equal(
+    expect_warning(deadspace_anatomic_child(ideal_weight_kg = 10)), 22)
   expect_equal(deadspace_anatomic_child(ideal_weight_kg = 10, age_y = 5),
                22.76615, tolerance = 1e-5)
 })
